@@ -30,6 +30,7 @@
 
 #include <QHostInfo>
 #include <QTcpServer>
+#include <QNetworkProxy>
 #include <QUdpSocket>
 #include <QNetworkSession>
 #include <QNetworkConfigurationManager>
@@ -44,18 +45,21 @@
 #define MIN_VERSION_WITH_SSL_SUPPORT 6
 
 LanLinkProvider::LanLinkProvider(bool testMode)
-    : mTestMode(testMode)
+    : m_testMode(testMode)
 {
-    mTcpPort = 0;
+    m_tcpPort = 0;
 
-    combineBroadcastsTimer.setInterval(0); // increase this if waiting a single event-loop iteration is not enough
-    combineBroadcastsTimer.setSingleShot(true);
-    connect(&combineBroadcastsTimer, SIGNAL(timeout()), this, SLOT(broadcastToNetwork()));
+    m_combineBroadcastsTimer.setInterval(0); // increase this if waiting a single event-loop iteration is not enough
+    m_combineBroadcastsTimer.setSingleShot(true);
+    connect(&m_combineBroadcastsTimer, &QTimer::timeout, this, &LanLinkProvider::broadcastToNetwork);
 
-    connect(&mUdpSocket, SIGNAL(readyRead()), this, SLOT(newUdpConnection()));
+    connect(&m_udpSocket, &QIODevice::readyRead, this, &LanLinkProvider::newUdpConnection);
 
-    mServer = new Server(this);
-    connect(mServer,SIGNAL(newConnection()),this, SLOT(newConnection()));
+    m_server = new Server(this);
+    m_server->setProxy(QNetworkProxy::NoProxy);
+    connect(m_server,&QTcpServer::newConnection,this, &LanLinkProvider::newConnection);
+
+    m_udpSocket.setProxy(QNetworkProxy::NoProxy);
 
     //Detect when a network interface changes status, so we announce ourelves in the new network
     QNetworkConfigurationManager* networkManager = new QNetworkConfigurationManager(this);
@@ -63,7 +67,7 @@ LanLinkProvider::LanLinkProvider(bool testMode)
 
 }
 
-void LanLinkProvider::onNetworkConfigurationChanged(const QNetworkConfiguration &config)
+void LanLinkProvider::onNetworkConfigurationChanged(const QNetworkConfiguration& config)
 {
     if (m_lastConfig != config && config.state() == QNetworkConfiguration::Active) {
         m_lastConfig = config;
@@ -77,19 +81,19 @@ LanLinkProvider::~LanLinkProvider()
 
 void LanLinkProvider::onStart()
 {
-    const QHostAddress bindAddress = mTestMode? QHostAddress::LocalHost : QHostAddress::Any;
+    const QHostAddress bindAddress = m_testMode? QHostAddress::LocalHost : QHostAddress::Any;
 
-    bool success = mUdpSocket.bind(bindAddress, PORT, QUdpSocket::ShareAddress);
+    bool success = m_udpSocket.bind(bindAddress, UDP_PORT, QUdpSocket::ShareAddress);
     Q_ASSERT(success);
 
     qCDebug(KDECONNECT_CORE) << "onStart";
 
-    mTcpPort = PORT;
-    while (!mServer->listen(bindAddress, mTcpPort)) {
-        mTcpPort++;
-        if (mTcpPort > 1764) { //No ports available?
-            qCritical(KDECONNECT_CORE) << "Error opening a port in range 1714-1764";
-            mTcpPort = 0;
+    m_tcpPort = MIN_TCP_PORT;
+    while (!m_server->listen(bindAddress, m_tcpPort)) {
+        m_tcpPort++;
+        if (m_tcpPort > MAX_TCP_PORT) { //No ports available?
+            qCritical(KDECONNECT_CORE) << "Error opening a port in range" << MIN_TCP_PORT << "-" << MAX_TCP_PORT;
+            m_tcpPort = 0;
             return;
         }
     }
@@ -100,78 +104,105 @@ void LanLinkProvider::onStart()
 void LanLinkProvider::onStop()
 {
     qCDebug(KDECONNECT_CORE) << "onStop";
-    mUdpSocket.close();
-    mServer->close();
+    m_udpSocket.close();
+    m_server->close();
 }
 
 void LanLinkProvider::onNetworkChange()
 {
-    if (combineBroadcastsTimer.isActive()) {
+    if (m_combineBroadcastsTimer.isActive()) {
         qCDebug(KDECONNECT_CORE()) << "Preventing duplicate broadcasts";
         return;
     }
-    combineBroadcastsTimer.start();
+    m_combineBroadcastsTimer.start();
 }
 
 //I'm in a new network, let's be polite and introduce myself
 void LanLinkProvider::broadcastToNetwork()
 {
 
-    if (!mServer->isListening()) {
+    if (!m_server->isListening()) {
         //Not started
         return;
     }
 
-    Q_ASSERT(mTcpPort != 0);
+    Q_ASSERT(m_tcpPort != 0);
 
     qCDebug(KDECONNECT_CORE()) << "Broadcasting identity packet";
-    NetworkPackage np("");
-    NetworkPackage::createIdentityPackage(&np);
-    np.set("tcpPort", mTcpPort);
-    mUdpSocket.writeDatagram(np.serialize(), mTestMode ? QHostAddress::LocalHost : QHostAddress("255.255.255.255"), PORT);
+
+    QHostAddress destAddress = m_testMode? QHostAddress::LocalHost : QHostAddress(QStringLiteral("255.255.255.255"));
+
+    NetworkPacket np(QLatin1String(""));
+    NetworkPacket::createIdentityPacket(&np);
+    np.set(QStringLiteral("tcpPort"), m_tcpPort);
+
+#ifdef Q_OS_WIN
+    //On Windows we need to broadcast from every local IP address to reach all networks
+    QUdpSocket sendSocket;
+    sendSocket.setProxy(QNetworkProxy::NoProxy);
+    for (const QNetworkInterface& iface : QNetworkInterface::allInterfaces()) {
+        if ( (iface.flags() & QNetworkInterface::IsUp)
+          && (iface.flags() & QNetworkInterface::IsRunning)
+          && (iface.flags() & QNetworkInterface::CanBroadcast)) {
+            for (const QNetworkAddressEntry& ifaceAddress : iface.addressEntries()) {
+                QHostAddress sourceAddress = ifaceAddress.ip();
+                if (sourceAddress.protocol() == QAbstractSocket::IPv4Protocol && sourceAddress != QHostAddress::LocalHost) {
+                    qCDebug(KDECONNECT_CORE()) << "Broadcasting as" << sourceAddress;
+                    sendSocket.bind(sourceAddress, UDP_PORT);
+                    sendSocket.writeDatagram(np.serialize(), destAddress, UDP_PORT);
+                    sendSocket.close();
+                }
+            }
+        }
+    }
+#else
+    m_udpSocket.writeDatagram(np.serialize(), destAddress, UDP_PORT);
+#endif
+
 }
 
 //I'm the existing device, a new device is kindly introducing itself.
 //I will create a TcpSocket and try to connect. This can result in either connected() or connectError().
 void LanLinkProvider::newUdpConnection() //udpBroadcastReceived
 {
-    while (mUdpSocket.hasPendingDatagrams()) {
+    while (m_udpSocket.hasPendingDatagrams()) {
 
         QByteArray datagram;
-        datagram.resize(mUdpSocket.pendingDatagramSize());
+        datagram.resize(m_udpSocket.pendingDatagramSize());
         QHostAddress sender;
 
-        mUdpSocket.readDatagram(datagram.data(), datagram.size(), &sender);
+        m_udpSocket.readDatagram(datagram.data(), datagram.size(), &sender);
 
-        if (sender.isLoopback() && !mTestMode)
+        if (sender.isLoopback() && !m_testMode)
             continue;
 
-        NetworkPackage* receivedPackage = new NetworkPackage("");
-        bool success = NetworkPackage::unserialize(datagram, receivedPackage);
+        NetworkPacket* receivedPacket = new NetworkPacket(QLatin1String(""));
+        bool success = NetworkPacket::unserialize(datagram, receivedPacket);
 
-        //qCDebug(KDECONNECT_CORE) << "udp connection from " << receivedPackage->;
+        //qCDebug(KDECONNECT_CORE) << "udp connection from " << receivedPacket->;
 
         //qCDebug(KDECONNECT_CORE) << "Datagram " << datagram.data() ;
 
-        if (!success || receivedPackage->type() != PACKAGE_TYPE_IDENTITY) {
-            delete receivedPackage;
+        if (!success || receivedPacket->type() != PACKET_TYPE_IDENTITY) {
+            delete receivedPacket;
             continue;
         }
 
-        if (receivedPackage->get<QString>("deviceId") == KdeConnectConfig::instance()->deviceId()) {
+        if (receivedPacket->get<QString>(QStringLiteral("deviceId")) == KdeConnectConfig::instance()->deviceId()) {
             //qCDebug(KDECONNECT_CORE) << "Ignoring my own broadcast";
-            delete receivedPackage;
+            delete receivedPacket;
             continue;
         }
 
-        int tcpPort = receivedPackage->get<int>("tcpPort", PORT);
+        int tcpPort = receivedPacket->get<int>(QStringLiteral("tcpPort"));
 
-        //qCDebug(KDECONNECT_CORE) << "Received Udp identity package from" << sender << " asking for a tcp connection on port " << tcpPort;
+        //qCDebug(KDECONNECT_CORE) << "Received Udp identity packet from" << sender << " asking for a tcp connection on port " << tcpPort;
 
         QSslSocket* socket = new QSslSocket(this);
-        receivedIdentityPackages[socket].np = receivedPackage;
-        receivedIdentityPackages[socket].sender = sender;
-        connect(socket, SIGNAL(connected()), this, SLOT(connected()));
+        socket->setProxy(QNetworkProxy::NoProxy);
+        m_receivedIdentityPackets[socket].np = receivedPacket;
+        m_receivedIdentityPackets[socket].sender = sender;
+        connect(socket, &QAbstractSocket::connected, this, &LanLinkProvider::connected);
         connect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(connectError()));
         socket->connectToHost(sender, tcpPort);
     }
@@ -181,43 +212,42 @@ void LanLinkProvider::connectError()
 {
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
     if (!socket) return;
-    disconnect(socket, SIGNAL(connected()), this, SLOT(connected()));
+    disconnect(socket, &QAbstractSocket::connected, this, &LanLinkProvider::connected);
     disconnect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(connectError()));
 
     qCDebug(KDECONNECT_CORE) << "Fallback (1), try reverse connection (send udp packet)" << socket->errorString();
-    NetworkPackage np("");
-    NetworkPackage::createIdentityPackage(&np);
-    np.set("tcpPort", mTcpPort);
-    mUdpSocket.writeDatagram(np.serialize(), receivedIdentityPackages[socket].sender, PORT);
+    NetworkPacket np(QLatin1String(""));
+    NetworkPacket::createIdentityPacket(&np);
+    np.set(QStringLiteral("tcpPort"), m_tcpPort);
+    m_udpSocket.writeDatagram(np.serialize(), m_receivedIdentityPackets[socket].sender, UDP_PORT);
 
     //The socket we created didn't work, and we didn't manage
     //to create a LanDeviceLink from it, deleting everything.
-    delete receivedIdentityPackages.take(socket).np;
+    delete m_receivedIdentityPackets.take(socket).np;
     delete socket;
 }
 
-//We received a UDP package and answered by connecting to them by TCP. This gets called on a succesful connection.
+//We received a UDP packet and answered by connecting to them by TCP. This gets called on a succesful connection.
 void LanLinkProvider::connected()
 {
-    qCDebug(KDECONNECT_CORE) << "Socket connected";
-
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
+
     if (!socket) return;
-    disconnect(socket, SIGNAL(connected()), this, SLOT(connected()));
+    disconnect(socket, &QAbstractSocket::connected, this, &LanLinkProvider::connected);
     disconnect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(connectError()));
 
     configureSocket(socket);
 
-    // If socket disconnects due to any reason after connection, link on ssl faliure
-    connect(socket, SIGNAL(disconnected()), socket, SLOT(deleteLater()));
+    // If socket disconnects due to any reason after connection, link on ssl failure
+    connect(socket, &QAbstractSocket::disconnected, socket, &QObject::deleteLater);
 
-    NetworkPackage* receivedPackage = receivedIdentityPackages[socket].np;
-    const QString& deviceId = receivedPackage->get<QString>("deviceId");
+    NetworkPacket* receivedPacket = m_receivedIdentityPackets[socket].np;
+    const QString& deviceId = receivedPacket->get<QString>(QStringLiteral("deviceId"));
     //qCDebug(KDECONNECT_CORE) << "Connected" << socket->isWritable();
 
     // If network is on ssl, do not believe when they are connected, believe when handshake is completed
-    NetworkPackage np2("");
-    NetworkPackage::createIdentityPackage(&np2);
+    NetworkPacket np2(QLatin1String(""));
+    NetworkPacket::createIdentityPacket(&np2);
     socket->write(np2.serialize());
     bool success = socket->waitForBytesWritten();
 
@@ -226,14 +256,14 @@ void LanLinkProvider::connected()
         qCDebug(KDECONNECT_CORE) << "TCP connection done (i'm the existing device)";
 
         // if ssl supported
-        if (receivedPackage->get<int>("protocolVersion") >= MIN_VERSION_WITH_SSL_SUPPORT) {
+        if (receivedPacket->get<int>(QStringLiteral("protocolVersion")) >= MIN_VERSION_WITH_SSL_SUPPORT) {
 
             bool isDeviceTrusted = KdeConnectConfig::instance()->trustedDevices().contains(deviceId);
             configureSslSocket(socket, deviceId, isDeviceTrusted);
 
             qCDebug(KDECONNECT_CORE) << "Starting server ssl (I'm the client TCP socket)";
 
-            connect(socket, SIGNAL(encrypted()), this, SLOT(encrypted()));
+            connect(socket, &QSslSocket::encrypted, this, &LanLinkProvider::encrypted);
 
             if (isDeviceTrusted) {
                 connect(socket, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(sslErrors(QList<QSslError>)));
@@ -241,20 +271,20 @@ void LanLinkProvider::connected()
 
             socket->startServerEncryption();
 
-            return; // Return statement prevents from deleting received package, needed in slot "encrypted"
+            return; // Return statement prevents from deleting received packet, needed in slot "encrypted"
         } else {
-            qWarning() << receivedPackage->get<QString>("deviceName") << "uses an old protocol version, this won't work";
-            //addLink(deviceId, socket, receivedPackage, LanDeviceLink::Remotely);
+            qWarning() << receivedPacket->get<QString>(QStringLiteral("deviceName")) << "uses an old protocol version, this won't work";
+            //addLink(deviceId, socket, receivedPacket, LanDeviceLink::Remotely);
         }
 
     } else {
         //I think this will never happen, but if it happens the deviceLink
         //(or the socket that is now inside it) might not be valid. Delete them.
         qCDebug(KDECONNECT_CORE) << "Fallback (2), try reverse connection (send udp packet)";
-        mUdpSocket.writeDatagram(np2.serialize(), receivedIdentityPackages[socket].sender, PORT);
+        m_udpSocket.writeDatagram(np2.serialize(), m_receivedIdentityPackets[socket].sender, UDP_PORT);
     }
 
-    delete receivedIdentityPackages.take(socket).np;
+    delete m_receivedIdentityPackets.take(socket).np;
     //We don't delete the socket because now it's owned by the LanDeviceLink
 }
 
@@ -264,19 +294,19 @@ void LanLinkProvider::encrypted()
 
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
     if (!socket) return;
-    disconnect(socket, SIGNAL(encrypted()), this, SLOT(encrypted()));
+    disconnect(socket, &QSslSocket::encrypted, this, &LanLinkProvider::encrypted);
     disconnect(socket, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(sslErrors(QList<QSslError>)));
 
     Q_ASSERT(socket->mode() != QSslSocket::UnencryptedMode);
     LanDeviceLink::ConnectionStarted connectionOrigin = (socket->mode() == QSslSocket::SslClientMode)? LanDeviceLink::Locally : LanDeviceLink::Remotely;
 
-    NetworkPackage* receivedPackage = receivedIdentityPackages[socket].np;
-    const QString& deviceId = receivedPackage->get<QString>("deviceId");
+    NetworkPacket* receivedPacket = m_receivedIdentityPackets[socket].np;
+    const QString& deviceId = receivedPacket->get<QString>(QStringLiteral("deviceId"));
 
-    addLink(deviceId, socket, receivedPackage, connectionOrigin);
+    addLink(deviceId, socket, receivedPacket, connectionOrigin);
 
-    // Copied from connected slot, now delete received package
-    delete receivedIdentityPackages.take(socket).np;
+    // Copied from connected slot, now delete received packet
+    delete m_receivedIdentityPackets.take(socket).np;
 }
 
 void LanLinkProvider::sslErrors(const QList<QSslError>& errors)
@@ -284,53 +314,39 @@ void LanLinkProvider::sslErrors(const QList<QSslError>& errors)
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
     if (!socket) return;
 
-    disconnect(socket, SIGNAL(encrypted()), this, SLOT(encrypted()));
+    disconnect(socket, &QSslSocket::encrypted, this, &LanLinkProvider::encrypted);
     disconnect(socket, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(sslErrors(QList<QSslError>)));
 
-    Q_FOREACH (const QSslError &error, errors) {
-        switch (error.error()) {
-            case QSslError::CertificateSignatureFailed:
-            case QSslError::CertificateNotYetValid:
-            case QSslError::CertificateExpired:
-            case QSslError::CertificateUntrusted:
-            case QSslError::SelfSignedCertificate: {
-                qCDebug(KDECONNECT_CORE) << "Failing due to " << error.errorString();
-                // Due to simultaneous multiple connections, it may be possible that device instance does not exist anymore
-                Device *device = Daemon::instance()->getDevice(socket->peerVerifyName());
-                if (device != Q_NULLPTR) {
-                    device->unpair();
-                }
-                break;
-            }
-            default:
-                continue;
-        }
+    qCDebug(KDECONNECT_CORE) << "Failing due to " << errors;
+    Device* device = Daemon::instance()->getDevice(socket->peerVerifyName());
+    if (device) {
+        device->unpair();
     }
 
-    delete receivedIdentityPackages.take(socket).np;
+    delete m_receivedIdentityPackets.take(socket).np;
     // Socket disconnects itself on ssl error and will be deleted by deleteLater slot, no need to delete manually
 }
 
-//I'm the new device and this is the answer to my UDP identity package (no data received yet). They are connecting to us through TCP, and they should send an identity.
+//I'm the new device and this is the answer to my UDP identity packet (no data received yet). They are connecting to us through TCP, and they should send an identity.
 void LanLinkProvider::newConnection()
 {
     //qCDebug(KDECONNECT_CORE) << "LanLinkProvider newConnection";
 
-    while (mServer->hasPendingConnections()) {
-        QSslSocket* socket = mServer->nextPendingConnection();
+    while (m_server->hasPendingConnections()) {
+        QSslSocket* socket = m_server->nextPendingConnection();
         configureSocket(socket);
         //This socket is still managed by us (and child of the QTcpServer), if
         //it disconnects before we manage to pass it to a LanDeviceLink, it's
         //our responsibility to delete it. We do so with this connection.
-        connect(socket, SIGNAL(disconnected()),
-                socket, SLOT(deleteLater()));
-        connect(socket, SIGNAL(readyRead()),
-                this, SLOT(dataReceived()));
+        connect(socket, &QAbstractSocket::disconnected,
+                socket, &QObject::deleteLater);
+        connect(socket, &QIODevice::readyRead,
+                this, &LanLinkProvider::dataReceived);
 
     }
 }
 
-//I'm the new device and this is the answer to my UDP identity package (data received)
+//I'm the new device and this is the answer to my UDP identity packet (data received)
 void LanLinkProvider::dataReceived()
 {
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
@@ -339,37 +355,37 @@ void LanLinkProvider::dataReceived()
 
     //qCDebug(KDECONNECT_CORE) << "LanLinkProvider received reply:" << data;
 
-    NetworkPackage* np = new NetworkPackage("");
-    bool success = NetworkPackage::unserialize(data, np);
+    NetworkPacket* np = new NetworkPacket(QLatin1String(""));
+    bool success = NetworkPacket::unserialize(data, np);
 
     if (!success) {
         delete np;
         return;
     }
 
-    if (np->type() != PACKAGE_TYPE_IDENTITY) {
+    if (np->type() != PACKET_TYPE_IDENTITY) {
         qCWarning(KDECONNECT_CORE) << "LanLinkProvider/newConnection: Expected identity, received " << np->type();
         delete np;
         return;
     }
 
     // Needed in "encrypted" if ssl is used, similar to "connected"
-    receivedIdentityPackages[socket].np = np;
+    m_receivedIdentityPackets[socket].np = np;
 
-    const QString& deviceId = np->get<QString>("deviceId");
+    const QString& deviceId = np->get<QString>(QStringLiteral("deviceId"));
     //qCDebug(KDECONNECT_CORE) << "Handshaking done (i'm the new device)";
 
     //This socket will now be owned by the LanDeviceLink or we don't want more data to be received, forget about it
-    disconnect(socket, SIGNAL(readyRead()), this, SLOT(dataReceived()));
+    disconnect(socket, &QIODevice::readyRead, this, &LanLinkProvider::dataReceived);
 
-    if (np->get<int>("protocolVersion") >= MIN_VERSION_WITH_SSL_SUPPORT) {
+    if (np->get<int>(QStringLiteral("protocolVersion")) >= MIN_VERSION_WITH_SSL_SUPPORT) {
 
         bool isDeviceTrusted = KdeConnectConfig::instance()->trustedDevices().contains(deviceId);
         configureSslSocket(socket, deviceId, isDeviceTrusted);
 
         qCDebug(KDECONNECT_CORE) << "Starting client ssl (but I'm the server TCP socket)";
 
-        connect(socket, SIGNAL(encrypted()), this, SLOT(encrypted()));
+        connect(socket, &QSslSocket::encrypted, this, &LanLinkProvider::encrypted);
 
         if (isDeviceTrusted) {
             connect(socket, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(sslErrors(QList<QSslError>)));
@@ -378,9 +394,9 @@ void LanLinkProvider::dataReceived()
         socket->startClientEncryption();
 
     } else {
-        qWarning() << np->get<QString>("deviceName") << "uses an old protocol version, this won't work";
+        qWarning() << np->get<QString>(QStringLiteral("deviceName")) << "uses an old protocol version, this won't work";
         //addLink(deviceId, socket, np, LanDeviceLink::Locally);
-        delete receivedIdentityPackages.take(socket).np;
+        delete m_receivedIdentityPackets.take(socket).np;
     }
 }
 
@@ -388,12 +404,15 @@ void LanLinkProvider::deviceLinkDestroyed(QObject* destroyedDeviceLink)
 {
     const QString id = destroyedDeviceLink->property("deviceId").toString();
     //qCDebug(KDECONNECT_CORE) << "deviceLinkDestroyed" << id;
-    Q_ASSERT(mLinks.key(static_cast<LanDeviceLink*>(destroyedDeviceLink)) == id);
-    QMap< QString, LanDeviceLink* >::iterator linkIterator = mLinks.find(id);
-    if (linkIterator != mLinks.end()) {
+    QMap< QString, LanDeviceLink* >::iterator linkIterator = m_links.find(id);
+    Q_ASSERT(linkIterator != m_links.end());
+    if (linkIterator != m_links.end()) {
         Q_ASSERT(linkIterator.value() == destroyedDeviceLink);
-        mLinks.erase(linkIterator);
-        mPairingHandlers.remove(id);
+        m_links.erase(linkIterator);
+        auto pairingHandler = m_pairingHandlers.take(id);
+        if (pairingHandler) {
+            pairingHandler->deleteLater();
+        }
     }
 
 }
@@ -404,11 +423,12 @@ void LanLinkProvider::configureSslSocket(QSslSocket* socket, const QString& devi
     // Top 3 ciphers are for new Android devices, botton two are for old Android devices
     // FIXME : These cipher suites should be checked whether they are supported or not on device
     QList<QSslCipher> socketCiphers;
-    socketCiphers.append(QSslCipher("ECDHE-ECDSA-AES256-GCM-SHA384"));
-    socketCiphers.append(QSslCipher("ECDHE-ECDSA-AES128-GCM-SHA256"));
-    socketCiphers.append(QSslCipher("ECDHE-RSA-AES128-SHA"));
-    socketCiphers.append(QSslCipher("RC4-SHA"));
-    socketCiphers.append(QSslCipher("RC4-MD5"));
+    socketCiphers.append(QSslCipher(QStringLiteral("ECDHE-ECDSA-AES256-GCM-SHA384")));
+    socketCiphers.append(QSslCipher(QStringLiteral("ECDHE-ECDSA-AES128-GCM-SHA256")));
+    socketCiphers.append(QSslCipher(QStringLiteral("ECDHE-RSA-AES128-SHA")));
+    socketCiphers.append(QSslCipher(QStringLiteral("RC4-SHA")));
+    socketCiphers.append(QSslCipher(QStringLiteral("RC4-MD5")));
+    socketCiphers.append(QSslCipher(QStringLiteral("DHE-RSA-AES256-SHA")));
 
     // Configure for ssl
     QSslConfiguration sslConfig;
@@ -421,7 +441,7 @@ void LanLinkProvider::configureSslSocket(QSslSocket* socket, const QString& devi
     socket->setPeerVerifyName(deviceId);
 
     if (isDeviceTrusted) {
-        QString certString = KdeConnectConfig::instance()->getDeviceProperty(deviceId, "certificate", QString());
+        QString certString = KdeConnectConfig::instance()->getDeviceProperty(deviceId, QStringLiteral("certificate"), QString());
         socket->addCaCertificate(QSslCertificate(certString.toLatin1()));
         socket->setPeerVerifyMode(QSslSocket::VerifyPeer);
     } else {
@@ -431,7 +451,7 @@ void LanLinkProvider::configureSslSocket(QSslSocket* socket, const QString& devi
     //Usually SSL errors are only bad for trusted devices. Uncomment this section to log errors in any case, for debugging.
     //QObject::connect(socket, static_cast<void (QSslSocket::*)(const QList<QSslError>&)>(&QSslSocket::sslErrors), [](const QList<QSslError>& errors)
     //{
-    //    Q_FOREACH (const QSslError &error, errors) {
+    //    Q_FOREACH (const QSslError& error, errors) {
     //        qCDebug(KDECONNECT_CORE) << "SSL Error:" << error.errorString();
     //    }
     //});
@@ -439,6 +459,8 @@ void LanLinkProvider::configureSslSocket(QSslSocket* socket, const QString& devi
 
 void LanLinkProvider::configureSocket(QSslSocket* socket) {
 
+    socket->setProxy(QNetworkProxy::NoProxy);
+
     socket->setSocketOption(QAbstractSocket::KeepAliveOption, QVariant(1));
 
     #ifdef TCP_KEEPIDLE
@@ -461,60 +483,59 @@ void LanLinkProvider::configureSocket(QSslSocket* socket) {
 
 }
 
-void LanLinkProvider::addLink(const QString& deviceId, QSslSocket* socket, NetworkPackage* receivedPackage, LanDeviceLink::ConnectionStarted connectionOrigin)
+void LanLinkProvider::addLink(const QString& deviceId, QSslSocket* socket, NetworkPacket* receivedPacket, LanDeviceLink::ConnectionStarted connectionOrigin)
 {
     // Socket disconnection will now be handled by LanDeviceLink
-    disconnect(socket, SIGNAL(disconnected()), socket, SLOT(deleteLater()));
+    disconnect(socket, &QAbstractSocket::disconnected, socket, &QObject::deleteLater);
 
     LanDeviceLink* deviceLink;
     //Do we have a link for this device already?
-    QMap< QString, LanDeviceLink* >::iterator linkIterator = mLinks.find(deviceId);
-    if (linkIterator != mLinks.end()) {
+    QMap< QString, LanDeviceLink* >::iterator linkIterator = m_links.find(deviceId);
+    if (linkIterator != m_links.end()) {
         //qCDebug(KDECONNECT_CORE) << "Reusing link to" << deviceId;
         deviceLink = linkIterator.value();
         deviceLink->reset(socket, connectionOrigin);
     } else {
         deviceLink = new LanDeviceLink(deviceId, this, socket, connectionOrigin);
-        connect(deviceLink, SIGNAL(destroyed(QObject*)), this, SLOT(deviceLinkDestroyed(QObject*)));
-        mLinks[deviceId] = deviceLink;
-        if (mPairingHandlers.contains(deviceId)) {
+        connect(deviceLink, &QObject::destroyed, this, &LanLinkProvider::deviceLinkDestroyed);
+        m_links[deviceId] = deviceLink;
+        if (m_pairingHandlers.contains(deviceId)) {
             //We shouldn't have a pairinghandler if we didn't have a link.
             //Crash if debug, recover if release (by setting the new devicelink to the old pairinghandler)
-            Q_ASSERT(mPairingHandlers.contains(deviceId));
-            mPairingHandlers[deviceId]->setDeviceLink(deviceLink);
+            Q_ASSERT(m_pairingHandlers.contains(deviceId));
+            m_pairingHandlers[deviceId]->setDeviceLink(deviceLink);
         }
-        Q_EMIT onConnectionReceived(*receivedPackage, deviceLink);
     }
-
+    Q_EMIT onConnectionReceived(*receivedPacket, deviceLink);
 }
 
 LanPairingHandler* LanLinkProvider::createPairingHandler(DeviceLink* link)
 {
-    LanPairingHandler* ph = mPairingHandlers.value(link->deviceId());
+    LanPairingHandler* ph = m_pairingHandlers.value(link->deviceId());
     if (!ph) {
         ph = new LanPairingHandler(link);
         qCDebug(KDECONNECT_CORE) << "creating pairing handler for" << link->deviceId();
         connect (ph, &LanPairingHandler::pairingError, link, &DeviceLink::pairingError);
-        mPairingHandlers[link->deviceId()] = ph;
+        m_pairingHandlers[link->deviceId()] = ph;
     }
     return ph;
 }
 
 void LanLinkProvider::userRequestsPair(const QString& deviceId)
 {
-    LanPairingHandler* ph = createPairingHandler(mLinks.value(deviceId));
+    LanPairingHandler* ph = createPairingHandler(m_links.value(deviceId));
     ph->requestPairing();
 }
 
 void LanLinkProvider::userRequestsUnpair(const QString& deviceId)
 {
-    LanPairingHandler* ph = createPairingHandler(mLinks.value(deviceId));
+    LanPairingHandler* ph = createPairingHandler(m_links.value(deviceId));
     ph->unpair();
 }
 
-void LanLinkProvider::incomingPairPackage(DeviceLink* deviceLink, const NetworkPackage& np)
+void LanLinkProvider::incomingPairPacket(DeviceLink* deviceLink, const NetworkPacket& np)
 {
     LanPairingHandler* ph = createPairingHandler(deviceLink);
-    ph->packageReceived(np);
+    ph->packetReceived(np);
 }
 
