@@ -20,10 +20,6 @@
 
 #include "device.h"
 
-#ifdef interface // MSVC language extension, QDBusConnection uses this as a variable name
-#undef interface
-#endif
-
 #include <QDBusConnection>
 #include <QSslCertificate>
 
@@ -35,14 +31,13 @@
 #include "kdeconnectplugin.h"
 #include "pluginloader.h"
 #include "backends/devicelink.h"
+#include "backends/lan/landevicelink.h"
 #include "backends/linkprovider.h"
-#include "networkpackage.h"
+#include "networkpacket.h"
 #include "kdeconnectconfig.h"
 #include "daemon.h"
 
-Q_LOGGING_CATEGORY(KDECONNECT_CORE, "kdeconnect.core")
-
-static void warn(const QString &info)
+static void warn(const QString& info)
 {
     qWarning() << "Device pairing error" << info;
 }
@@ -50,7 +45,7 @@ static void warn(const QString &info)
 Device::Device(QObject* parent, const QString& id)
     : QObject(parent)
     , m_deviceId(id)
-    , m_protocolVersion(NetworkPackage::ProtocolVersion) //We don't know it yet
+    , m_protocolVersion(NetworkPacket::s_protocolVersion) //We don't know it yet
 {
     KdeConnectConfig::DeviceInfo info = KdeConnectConfig::instance()->getTrustedDevice(id);
 
@@ -66,12 +61,12 @@ Device::Device(QObject* parent, const QString& id)
     connect(this, &Device::pairingError, this, &warn);
 }
 
-Device::Device(QObject* parent, const NetworkPackage& identityPackage, DeviceLink* dl)
+Device::Device(QObject* parent, const NetworkPacket& identityPacket, DeviceLink* dl)
     : QObject(parent)
-    , m_deviceId(identityPackage.get<QString>("deviceId"))
-    , m_deviceName(identityPackage.get<QString>("deviceName"))
+    , m_deviceId(identityPacket.get<QString>(QStringLiteral("deviceId")))
+    , m_deviceName(identityPacket.get<QString>(QStringLiteral("deviceName")))
 {
-    addLink(identityPackage, dl);
+    addLink(identityPacket, dl);
 
     //Register in bus
     QDBusConnection::sessionBus().registerObject(dbusPath(), this, QDBusConnection::ExportScriptableContents | QDBusConnection::ExportAdaptors);
@@ -97,18 +92,18 @@ QStringList Device::loadedPlugins() const
 
 void Device::reloadPlugins()
 {
-    QHash<QString, KdeConnectPlugin*> newPluginMap;
+    QHash<QString, KdeConnectPlugin*> newPluginMap, oldPluginMap = m_plugins;
     QMultiMap<QString, KdeConnectPlugin*> newPluginsByIncomingCapability;
 
     if (isTrusted() && isReachable()) { //Do not load any plugin for unpaired devices, nor useless loading them for unreachable devices
 
         PluginLoader* loader = PluginLoader::instance();
 
-        Q_FOREACH (const QString& pluginName, m_supportedPlugins) {
+        for (const QString& pluginName : qAsConst(m_supportedPlugins)) {
             const KPluginMetaData service = loader->getPluginInfo(pluginName);
 
             const bool pluginEnabled = isPluginEnabled(pluginName);
-            const QSet<QString> incomingCapabilities = KPluginMetaData::readStringList(service.rawData(), "X-KdeConnect-SupportedPackageType").toSet();
+            const QSet<QString> incomingCapabilities = KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-SupportedPacketType")).toSet();
 
             if (pluginEnabled) {
                 KdeConnectPlugin* plugin = m_plugins.take(pluginName);
@@ -118,7 +113,7 @@ void Device::reloadPlugins()
                 }
                 Q_ASSERT(plugin);
 
-                Q_FOREACH (const QString& interface, incomingCapabilities) {
+                for (const QString& interface : incomingCapabilities) {
                     newPluginsByIncomingCapability.insert(interface, plugin);
                 }
 
@@ -127,7 +122,7 @@ void Device::reloadPlugins()
         }
     }
 
-    const bool differentPlugins = m_plugins != newPluginMap;
+    const bool differentPlugins = oldPluginMap != newPluginMap;
 
     //Erase all left plugins in the original map (meaning that we don't want
     //them anymore, otherwise they would have been moved to the newPluginMap)
@@ -135,9 +130,15 @@ void Device::reloadPlugins()
     m_plugins = newPluginMap;
     m_pluginsByIncomingCapability = newPluginsByIncomingCapability;
 
-    //TODO: see how it works in Android (only done once, when created)
-    Q_FOREACH(KdeConnectPlugin* plugin, m_plugins) {
+    QDBusConnection bus = QDBusConnection::sessionBus();
+    for (KdeConnectPlugin* plugin : qAsConst(m_plugins)) {
+        //TODO: see how it works in Android (only done once, when created)
         plugin->connected();
+
+        const QString dbusPath = plugin->dbusPath();
+        if (!dbusPath.isEmpty()) {
+            bus.registerObject(dbusPath, plugin, QDBusConnection::ExportAllProperties | QDBusConnection::ExportScriptableInvokables | QDBusConnection::ExportScriptableSignals | QDBusConnection::ExportScriptableSlots);
+        }
     }
     if (differentPlugins) {
         Q_EMIT pluginsChanged();
@@ -146,7 +147,7 @@ void Device::reloadPlugins()
 
 QString Device::pluginsConfigFile() const
 {
-    return KdeConnectConfig::instance()->deviceConfigDir(id()).absoluteFilePath("config");
+    return KdeConnectConfig::instance()->deviceConfigDir(id()).absoluteFilePath(QStringLiteral("config"));
 }
 
 void Device::requestPair()
@@ -161,17 +162,18 @@ void Device::requestPair()
         return;
     }
 
-    Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
+    for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
         dl->userRequestsPair();
     }
 }
 
 void Device::unpair()
 {
-    Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
+    for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
         dl->userRequestsUnpair();
     }
     KdeConnectConfig::instance()->removeTrustedDevice(id());
+    Q_EMIT trustedChanged(false);
 }
 
 void Device::pairStatusChanged(DeviceLink::PairStatus status)
@@ -179,7 +181,7 @@ void Device::pairStatusChanged(DeviceLink::PairStatus status)
     if (status == DeviceLink::NotPaired) {
         KdeConnectConfig::instance()->removeTrustedDevice(id());
 
-        Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
+        for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
             if (dl != sender()) {
                 dl->setPairStatus(DeviceLink::NotPaired);
             }
@@ -191,7 +193,7 @@ void Device::pairStatusChanged(DeviceLink::PairStatus status)
     reloadPlugins(); //Will load/unload plugins
 
     bool isTrusted = (status == DeviceLink::Paired);
-    Q_EMIT trustedChanged(isTrusted? Trusted : NotTrusted);
+    Q_EMIT trustedChanged(isTrusted);
     Q_ASSERT(isTrusted == this->isTrusted());
 }
 
@@ -200,39 +202,39 @@ static bool lessThan(DeviceLink* p1, DeviceLink* p2)
     return p1->provider()->priority() > p2->provider()->priority();
 }
 
-void Device::addLink(const NetworkPackage& identityPackage, DeviceLink* link)
+void Device::addLink(const NetworkPacket& identityPacket, DeviceLink* link)
 {
     //qCDebug(KDECONNECT_CORE) << "Adding link to" << id() << "via" << link->provider();
 
-    Q_ASSERT(!m_deviceLinks.contains(link));
+    setName(identityPacket.get<QString>(QStringLiteral("deviceName")));
+    m_deviceType = str2type(identityPacket.get<QString>(QStringLiteral("deviceType")));
 
-    m_protocolVersion = identityPackage.get<int>("protocolVersion", -1);
-    if (m_protocolVersion != NetworkPackage::ProtocolVersion) {
-        qCWarning(KDECONNECT_CORE) << m_deviceName << "- warning, device uses a different protocol version" << m_protocolVersion << "expected" << NetworkPackage::ProtocolVersion;
+    if (m_deviceLinks.contains(link))
+        return;
+
+    m_protocolVersion = identityPacket.get<int>(QStringLiteral("protocolVersion"), -1);
+    if (m_protocolVersion != NetworkPacket::s_protocolVersion) {
+        qCWarning(KDECONNECT_CORE) << m_deviceName << "- warning, device uses a different protocol version" << m_protocolVersion << "expected" << NetworkPacket::s_protocolVersion;
     }
 
-    connect(link, SIGNAL(destroyed(QObject*)),
-            this, SLOT(linkDestroyed(QObject*)));
+    connect(link, &QObject::destroyed,
+            this, &Device::linkDestroyed);
 
     m_deviceLinks.append(link);
 
-    //re-read the device name from the identityPackage because it could have changed
-    setName(identityPackage.get<QString>("deviceName"));
-    m_deviceType = str2type(identityPackage.get<QString>("deviceType"));
-
     //Theoretically we will never add two links from the same provider (the provider should destroy
     //the old one before this is called), so we do not have to worry about destroying old links.
     //-- Actually, we should not destroy them or the provider will store an invalid ref!
 
-    connect(link, SIGNAL(receivedPackage(NetworkPackage)),
-            this, SLOT(privateReceivedPackage(NetworkPackage)));
+    connect(link, &DeviceLink::receivedPacket,
+            this, &Device::privateReceivedPacket);
 
-    qSort(m_deviceLinks.begin(), m_deviceLinks.end(), lessThan);
+    std::sort(m_deviceLinks.begin(), m_deviceLinks.end(), lessThan);
 
-    const bool capabilitiesSupported = identityPackage.has("incomingCapabilities") || identityPackage.has("outgoingCapabilities");
+    const bool capabilitiesSupported = identityPacket.has(QStringLiteral("incomingCapabilities")) || identityPacket.has(QStringLiteral("outgoingCapabilities"));
     if (capabilitiesSupported) {
-        const QSet<QString> outgoingCapabilities = identityPackage.get<QStringList>("outgoingCapabilities").toSet()
-                          , incomingCapabilities = identityPackage.get<QStringList>("incomingCapabilities").toSet();
+        const QSet<QString> outgoingCapabilities = identityPacket.get<QStringList>(QStringLiteral("outgoingCapabilities")).toSet()
+                          , incomingCapabilities = identityPacket.get<QStringList>(QStringLiteral("incomingCapabilities")).toSet();
 
         m_supportedPlugins = PluginLoader::instance()->pluginsForCapabilities(incomingCapabilities, outgoingCapabilities);
         //qDebug() << "new plugins for" << m_deviceName << m_supportedPlugins << incomingCapabilities << outgoingCapabilities;
@@ -243,13 +245,60 @@ void Device::addLink(const NetworkPackage& identityPackage, DeviceLink* link)
     reloadPlugins();
 
     if (m_deviceLinks.size() == 1) {
-        Q_EMIT reachableStatusChanged();
+        Q_EMIT reachableChanged(true);
     }
 
     connect(link, &DeviceLink::pairStatusChanged, this, &Device::pairStatusChanged);
+    connect(link, &DeviceLink::pairingRequest, this, &Device::addPairingRequest);
+    connect(link, &DeviceLink::pairingRequestExpired, this, &Device::removePairingRequest);
     connect(link, &DeviceLink::pairingError, this, &Device::pairingError);
 }
 
+void Device::addPairingRequest(PairingHandler* handler)
+{
+    const bool wasEmpty = m_pairRequests.isEmpty();
+    m_pairRequests.insert(handler);
+
+    if (wasEmpty != m_pairRequests.isEmpty())
+        Q_EMIT hasPairingRequestsChanged(!m_pairRequests.isEmpty());
+}
+
+void Device::removePairingRequest(PairingHandler* handler)
+{
+    const bool wasEmpty = m_pairRequests.isEmpty();
+    m_pairRequests.remove(handler);
+
+    if (wasEmpty != m_pairRequests.isEmpty())
+        Q_EMIT hasPairingRequestsChanged(!m_pairRequests.isEmpty());
+}
+
+bool Device::hasPairingRequests() const
+{
+    return !m_pairRequests.isEmpty();
+}
+
+void Device::acceptPairing()
+{
+    if (m_pairRequests.isEmpty())
+        qWarning() << "no pair requests to accept!";
+
+    //copying because the pairing handler will be removed upon accept
+    const auto prCopy = m_pairRequests;
+    for (auto ph: prCopy)
+        ph->acceptPairing();
+}
+
+void Device::rejectPairing()
+{
+    if (m_pairRequests.isEmpty())
+        qWarning() << "no pair requests to reject!";
+
+    //copying because the pairing handler will be removed upon reject
+    const auto prCopy = m_pairRequests;
+    for (auto ph: prCopy)
+        ph->rejectPairing();
+}
+
 void Device::linkDestroyed(QObject* o)
 {
     removeLink(static_cast<DeviceLink*>(o));
@@ -263,36 +312,36 @@ void Device::removeLink(DeviceLink* link)
 
     if (m_deviceLinks.isEmpty()) {
         reloadPlugins();
-        Q_EMIT reachableStatusChanged();
+        Q_EMIT reachableChanged(false);
     }
 }
 
-bool Device::sendPackage(NetworkPackage& np)
+bool Device::sendPacket(NetworkPacket& np)
 {
-    Q_ASSERT(np.type() != PACKAGE_TYPE_PAIR);
+    Q_ASSERT(np.type() != PACKET_TYPE_PAIR);
     Q_ASSERT(isTrusted());
 
-    //Maybe we could block here any package that is not an identity or a pairing package to prevent sending non encrypted data
-    Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
-        if (dl->sendPackage(np)) return true;
+    //Maybe we could block here any packet that is not an identity or a pairing packet to prevent sending non encrypted data
+    for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
+        if (dl->sendPacket(np)) return true;
     }
 
     return false;
 }
 
-void Device::privateReceivedPackage(const NetworkPackage& np)
+void Device::privateReceivedPacket(const NetworkPacket& np)
 {
-    Q_ASSERT(np.type() != PACKAGE_TYPE_PAIR);
+    Q_ASSERT(np.type() != PACKET_TYPE_PAIR);
     if (isTrusted()) {
         const QList<KdeConnectPlugin*> plugins = m_pluginsByIncomingCapability.values(np.type());
         if (plugins.isEmpty()) {
-            qWarning() << "discarding unsupported package" << np.type() << "for" << name();
+            qWarning() << "discarding unsupported packet" << np.type() << "for" << name();
         }
-        Q_FOREACH (KdeConnectPlugin* plugin, plugins) {
-            plugin->receivePackage(np);
+        for (KdeConnectPlugin* plugin : plugins) {
+            plugin->receivePacket(np);
         }
     } else {
-        qCDebug(KDECONNECT_CORE) << "device" << name() << "not paired, ignoring package" << np.type();
+        qCDebug(KDECONNECT_CORE) << "device" << name() << "not paired, ignoring packet" << np.type();
         unpair();
     }
 
@@ -306,7 +355,8 @@ bool Device::isTrusted() const
 QStringList Device::availableLinks() const
 {
     QStringList sl;
-    Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
+    sl.reserve(m_deviceLinks.size());
+    for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
         sl.append(dl->provider()->name());
     }
     return sl;
@@ -327,20 +377,31 @@ void Device::cleanUnneededLinks() {
     }
 }
 
-Device::DeviceType Device::str2type(const QString &deviceType) {
-    if (deviceType == "desktop") return Desktop;
-    if (deviceType == "laptop") return Laptop;
-    if (deviceType == "smartphone" || deviceType == "phone") return Phone;
-    if (deviceType == "tablet") return Tablet;
+QHostAddress Device::getLocalIpAddress() const
+{
+    for (DeviceLink* dl : m_deviceLinks) {
+        LanDeviceLink* ldl = dynamic_cast<LanDeviceLink*>(dl);
+        if (ldl) {
+            return ldl->hostAddress();
+        }
+    }
+    return QHostAddress::Null;
+}
+
+Device::DeviceType Device::str2type(const QString& deviceType) {
+    if (deviceType == QLatin1String("desktop")) return Desktop;
+    if (deviceType == QLatin1String("laptop")) return Laptop;
+    if (deviceType == QLatin1String("smartphone") || deviceType == QLatin1String("phone")) return Phone;
+    if (deviceType == QLatin1String("tablet")) return Tablet;
     return Unknown;
 }
 
 QString Device::type2str(Device::DeviceType deviceType) {
-    if (deviceType == Desktop) return "desktop";
-    if (deviceType == Laptop) return "laptop";
-    if (deviceType == Phone) return "smartphone";
-    if (deviceType == Tablet) return "tablet";
-    return "unknown";
+    if (deviceType == Desktop) return QStringLiteral("desktop");
+    if (deviceType == Laptop) return QStringLiteral("laptop");
+    if (deviceType == Phone) return QStringLiteral("smartphone");
+    if (deviceType == Tablet) return QStringLiteral("tablet");
+    return QStringLiteral("unknown");
 }
 
 QString Device::statusIconName() const
@@ -366,10 +427,10 @@ QString Device::iconForStatus(bool reachable, bool trusted) const
     QString status = (reachable? (trusted? QStringLiteral("connected") : QStringLiteral("disconnected")) : QStringLiteral("trusted"));
     QString type = type2str(deviceType);
 
-    return type+'-'+status;
+    return type+status;
 }
 
-void Device::setName(const QString &name)
+void Device::setName(const QString& name)
 {
     if (m_deviceName != name) {
         m_deviceName = name;
@@ -406,15 +467,15 @@ QString Device::encryptionInfo() const
     QCryptographicHash::Algorithm digestAlgorithm = QCryptographicHash::Algorithm::Sha1;
 
     QString localSha1 = QString::fromLatin1(KdeConnectConfig::instance()->certificate().digest(digestAlgorithm).toHex());
-    for (int i=2 ; i<localSha1.size() ; i+=3) {
+    for (int i = 2; i<localSha1.size(); i += 3) {
         localSha1.insert(i, ':'); // Improve readability
     }
     result += i18n("SHA1 fingerprint of your device certificate is: %1\n", localSha1);
 
-    std::string  remotePem = KdeConnectConfig::instance()->getDeviceProperty(id(), "certificate").toStdString();
-    QSslCertificate remoteCertificate = QSslCertificate(QByteArray(remotePem.c_str(), remotePem.size()));
+    std::string  remotePem = KdeConnectConfig::instance()->getDeviceProperty(id(), QStringLiteral("certificate")).toStdString();
+    QSslCertificate remoteCertificate = QSslCertificate(QByteArray(remotePem.c_str(), (int)remotePem.size()));
     QString remoteSha1 = QString::fromLatin1(remoteCertificate.digest(digestAlgorithm).toHex());
-    for (int i=2 ; i<remoteSha1.size() ; i+=3) {
+    for (int i = 2; i < remoteSha1.size(); i += 3) {
         remoteSha1.insert(i, ':'); // Improve readability
     }
     result += i18n("SHA1 fingerprint of remote device certificate is: %1\n", remoteSha1);
