@@ -20,6 +20,7 @@
 
 #include <QApplication>
 #include <QNetworkAccessManager>
+#include <QTimer>
 
 #include <KDBusService>
 #include <KNotification>
@@ -41,16 +42,16 @@ public:
         , m_nam(Q_NULLPTR)
     {}
 
-    void askPairingConfirmation(PairingHandler* d) override
+    void askPairingConfirmation(Device* device) override
     {
-        KNotification* notification = new KNotification("pairingRequest");
+        KNotification* notification = new KNotification(QStringLiteral("pairingRequest"));
         notification->setIconName(QStringLiteral("dialog-information"));
-        notification->setComponentName("kdeconnect");
-        notification->setText(i18n("Pairing request from %1", getDevice(d->deviceLink()->deviceId())->name()));
+        notification->setComponentName(QStringLiteral("kdeconnect"));
+        notification->setText(i18n("Pairing request from %1", device->name().toHtmlEscaped()));
         notification->setActions(QStringList() << i18n("Accept") << i18n("Reject"));
-        connect(notification, &KNotification::ignored, d, &PairingHandler::rejectPairing);
-        connect(notification, &KNotification::action1Activated, d, &PairingHandler::acceptPairing);
-        connect(notification, &KNotification::action2Activated, d, &PairingHandler::rejectPairing);
+//         notification->setTimeout(PairingHandler::pairingTimeoutMsec());
+        connect(notification, &KNotification::action1Activated, device, &Device::acceptPairing);
+        connect(notification, &KNotification::action2Activated, device, &Device::rejectPairing);
         notification->sendEvent();
     }
 
@@ -67,6 +68,17 @@ public:
         return m_nam;
     }
 
+    Q_SCRIPTABLE void sendSimpleNotification(const QString &eventId, const QString &title, const QString &text, const QString &iconName) override
+    {
+        KNotification* notification = new KNotification(eventId); //KNotification::Persistent
+        notification->setIconName(iconName);
+        notification->setComponentName(QStringLiteral("kdeconnect"));
+        notification->setTitle(title);
+        notification->setText(text);
+        notification->sendEvent();
+    }
+
+
 private:
     QNetworkAccessManager* m_nam;
 };
@@ -74,9 +86,9 @@ private:
 int main(int argc, char* argv[])
 {
     QApplication app(argc, argv);
-    app.setApplicationName("kdeconnectd");
-    app.setApplicationVersion(QLatin1String(KDECONNECT_VERSION_STRING));
-    app.setOrganizationDomain("kde.org");
+    app.setApplicationName(QStringLiteral("kdeconnectd"));
+    app.setApplicationVersion(QStringLiteral(KDECONNECT_VERSION_STRING));
+    app.setOrganizationDomain(QStringLiteral("kde.org"));
     app.setQuitOnLastWindowClosed(false);
 
     KDBusService dbusService(KDBusService::Unique);
