@@ -36,15 +36,15 @@ NotificationsModel::NotificationsModel(QObject* parent)
 
     //new ModelTest(this, this);
 
-    connect(this, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SIGNAL(rowsChanged()));
-    connect(this, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            this, SIGNAL(rowsChanged()));
+    connect(this, &QAbstractItemModel::rowsInserted,
+            this, &NotificationsModel::rowsChanged);
+    connect(this, &QAbstractItemModel::rowsRemoved,
+            this, &NotificationsModel::rowsChanged);
 
-    connect(this, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            this, SIGNAL(anyDismissableChanged()));
-    connect(this, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SIGNAL(anyDismissableChanged()));
+    connect(this, &QAbstractItemModel::dataChanged,
+            this, &NotificationsModel::anyDismissableChanged);
+    connect(this, &QAbstractItemModel::rowsInserted,
+            this, &NotificationsModel::anyDismissableChanged);
 
     QDBusServiceWatcher* watcher = new QDBusServiceWatcher(DaemonDbusInterface::activatedService(),
                                                            QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
@@ -60,6 +60,10 @@ QHash<int, QByteArray> NotificationsModel::roleNames() const
     names.insert(AppNameModelRole,     "appName");
     names.insert(IdModelRole,          "notificationId");
     names.insert(DismissableModelRole, "dismissable");
+    names.insert(RepliableModelRole, "repliable");
+    names.insert(IconPathModelRole, "appIcon");
+    names.insert(TitleModelRole, "title");
+    names.insert(TextModelRole, "notitext");
     return names;
 }
 
@@ -82,12 +86,14 @@ void NotificationsModel::setDeviceId(const QString& deviceId)
 
     m_dbusInterface = new DeviceNotificationsDbusInterface(deviceId, this);
 
-    connect(m_dbusInterface, SIGNAL(notificationPosted(QString)),
-            this, SLOT(notificationAdded(QString)));
-    connect(m_dbusInterface, SIGNAL(notificationRemoved(QString)),
-            this, SLOT(notificationRemoved(QString)));
-    connect(m_dbusInterface, SIGNAL(allNotificationsRemoved()),
-            this, SLOT(clearNotifications()));
+    connect(m_dbusInterface, &OrgKdeKdeconnectDeviceNotificationsInterface::notificationPosted,
+            this, &NotificationsModel::notificationAdded);
+    connect(m_dbusInterface, &OrgKdeKdeconnectDeviceNotificationsInterface::notificationRemoved,
+            this, &NotificationsModel::notificationRemoved);
+    connect(m_dbusInterface, &OrgKdeKdeconnectDeviceNotificationsInterface::allNotificationsRemoved,
+            this, &NotificationsModel::clearNotifications);
+    connect(m_dbusInterface, &OrgKdeKdeconnectDeviceNotificationsInterface::notificationUpdated,
+            this, &NotificationsModel::notificationUpdated);
 
     refreshNotificationList();
 
@@ -96,10 +102,9 @@ void NotificationsModel::setDeviceId(const QString& deviceId)
 
 void NotificationsModel::notificationAdded(const QString& id)
 {
-    int currentSize = m_notificationList.size();
-    beginInsertRows(QModelIndex(),  currentSize, currentSize);
+    beginInsertRows(QModelIndex(),  0, 0);
     NotificationDbusInterface* dbusInterface = new NotificationDbusInterface(m_deviceId, id, this);
-    m_notificationList.append(dbusInterface);
+    m_notificationList.prepend(dbusInterface);
     endInsertRows();
 }
 
@@ -130,10 +135,10 @@ void NotificationsModel::refreshNotificationList()
     }
 
     QDBusPendingReply<QStringList> pendingNotificationIds = m_dbusInterface->activeNotifications();
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pendingNotificationIds, this);
+    QDBusPendingCallWatcher* watcher = new QDBusPendingCallWatcher(pendingNotificationIds, this);
 
-    QObject::connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)),
-                     this, SLOT(receivedNotifications(QDBusPendingCallWatcher*)));
+    QObject::connect(watcher, &QDBusPendingCallWatcher::finished,
+                     this, &NotificationsModel::receivedNotifications);
 }
 
 void NotificationsModel::receivedNotifications(QDBusPendingCallWatcher* watcher)
@@ -153,7 +158,7 @@ void NotificationsModel::receivedNotifications(QDBusPendingCallWatcher* watcher)
     }
 
     beginInsertRows(QModelIndex(), 0, notificationIds.size() - 1);
-    Q_FOREACH (const QString& notificationId, notificationIds) {
+    for (const QString& notificationId : notificationIds) {
         NotificationDbusInterface* dbusInterface = new NotificationDbusInterface(m_deviceId, notificationId, this);
         m_notificationList.append(dbusInterface);
     }
@@ -179,7 +184,7 @@ QVariant NotificationsModel::data(const QModelIndex& index, int role) const
     //FIXME: This function gets called lots of times, producing lots of dbus calls. Add a cache?
     switch (role) {
         case IconModelRole:
-            return QIcon::fromTheme("device-notifier");
+            return QIcon::fromTheme(QStringLiteral("device-notifier"));
         case IdModelRole:
             return notification->internalId();
         case NameModelRole:
@@ -192,6 +197,14 @@ QVariant NotificationsModel::data(const QModelIndex& index, int role) const
             return qVariantFromValue<QObject*>(notification);
         case DismissableModelRole:
             return notification->dismissable();
+        case RepliableModelRole:
+            return !notification->replyId().isEmpty();
+        case IconPathModelRole:
+            return notification->iconPath();
+        case TitleModelRole:
+            return notification->title();
+        case TextModelRole:
+            return notification->text();
         default:
              return QVariant();
     }
@@ -223,7 +236,7 @@ int NotificationsModel::rowCount(const QModelIndex& parent) const
 
 bool NotificationsModel::isAnyDimissable() const
 {
-    Q_FOREACH (NotificationDbusInterface* notification, m_notificationList) {
+    for (NotificationDbusInterface* notification : qAsConst(m_notificationList)) {
         if (notification->dismissable()) {
             return true;
         }
@@ -233,7 +246,7 @@ bool NotificationsModel::isAnyDimissable() const
 
 void NotificationsModel::dismissAll()
 {
-    Q_FOREACH (NotificationDbusInterface* notification, m_notificationList) {
+    for (NotificationDbusInterface* notification : qAsConst(m_notificationList)) {
         if (notification->dismissable()) {
             notification->dismiss();
         }
@@ -249,3 +262,10 @@ void NotificationsModel::clearNotifications()
         endRemoveRows();
     }
 }
+
+void NotificationsModel::notificationUpdated(const QString& id)
+{
+    //TODO only emit the affected indices
+    Q_UNUSED(id);
+    Q_EMIT dataChanged(index(0,0), index(m_notificationList.size() - 1, 0));
+}
