@@ -46,29 +46,27 @@ K_PLUGIN_FACTORY(KdeConnectKcmFactory, registerPlugin<KdeConnectKcm>();)
 
 static QString createId() { return QStringLiteral("kcm")+QString::number(QCoreApplication::applicationPid()); }
 
-KdeConnectKcm::KdeConnectKcm(QWidget *parent, const QVariantList&)
-    : KCModule(KAboutData::pluginData("kdeconnect-kcm"), parent)
+KdeConnectKcm::KdeConnectKcm(QWidget* parent, const QVariantList&)
+    : KCModule(KAboutData::pluginData(QStringLiteral("kdeconnect-kcm")), parent)
     , kcmUi(new Ui::KdeConnectKcmUi())
     , daemon(new DaemonDbusInterface(this))
     , devicesModel(new DevicesModel(this))
     , currentDevice(nullptr)
 {
-    KAboutData *about = new KAboutData("kdeconnect-kcm",
+    KAboutData* about = new KAboutData(QStringLiteral("kdeconnect-kcm"),
                                        i18n("KDE Connect Settings"),
-                                       QLatin1String(KDECONNECT_VERSION_STRING),
+                                       QStringLiteral(KDECONNECT_VERSION_STRING),
                                        i18n("KDE Connect Settings module"),
                                        KAboutLicense::KAboutLicense::GPL_V2,
                                        i18n("(C) 2015 Albert Vaca Cintora"),
                                        QString(),
-                                       QLatin1String("https://community.kde.org/KDEConnect")
+                                       QStringLiteral("https://community.kde.org/KDEConnect")
     );
     about->addAuthor(i18n("Albert Vaca Cintora"));
     setAboutData(about);
 
     kcmUi->setupUi(this);
 
-    kcmUi->deviceList->setIconSize(QSize(32,32));
-
     sortProxyModel = new DevicesSortProxyModel(devicesModel);
 
     kcmUi->deviceList->setModel(sortProxyModel);
@@ -81,30 +79,40 @@ KdeConnectKcm::KdeConnectKcm(QWidget *parent, const QVariantList&)
     kcmUi->noDeviceLinks->setWordWrap(false);
     QTimer::singleShot(0, [this] { kcmUi->noDeviceLinks->setWordWrap(true); });
 
-    kcmUi->rename_label->setText(daemon->announcedName());
-    kcmUi->rename_edit->setText(daemon->announcedName());
+    setWhenAvailable(daemon->announcedName(), [this](const QString& announcedName) {
+        kcmUi->rename_label->setText(announcedName);
+        kcmUi->rename_edit->setText(announcedName);
+    }, this);
+    connect(daemon, SIGNAL(announcedNameChanged(QString)),
+            kcmUi->rename_edit, SLOT(setText(QString)));
+    connect(daemon, SIGNAL(announcedNameChanged(QString)),
+            kcmUi->rename_label, SLOT(setText(QString)));
     setRenameMode(false);
 
     setButtons(KCModule::Help | KCModule::NoAdditionalButton);
 
-    connect(devicesModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            this, SLOT(resetSelection()));
-    connect(kcmUi->deviceList->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            this, SLOT(deviceSelected(QModelIndex)));
-    connect(kcmUi->pair_button, SIGNAL(clicked()),
-            this, SLOT(requestPair()));
-    connect(kcmUi->unpair_button, SIGNAL(clicked()),
-            this, SLOT(unpair()));
-    connect(kcmUi->ping_button, SIGNAL(clicked()),
-            this, SLOT(sendPing()));
-    connect(kcmUi->refresh_button,SIGNAL(clicked()),
-            this, SLOT(refresh()));
-    connect(kcmUi->rename_edit,SIGNAL(returnPressed()),
-            this, SLOT(renameDone()));
-    connect(kcmUi->renameDone_button,SIGNAL(clicked()),
-            this, SLOT(renameDone()));
-    connect(kcmUi->renameShow_button,SIGNAL(clicked()),
-            this, SLOT(renameShow()));
+    connect(devicesModel, &QAbstractItemModel::dataChanged,
+            this, &KdeConnectKcm::resetSelection);
+    connect(kcmUi->deviceList->selectionModel(), &QItemSelectionModel::currentChanged,
+            this, &KdeConnectKcm::deviceSelected);
+    connect(kcmUi->accept_button, &QAbstractButton::clicked,
+            this, &KdeConnectKcm::acceptPairing);
+    connect(kcmUi->reject_button, &QAbstractButton::clicked,
+            this, &KdeConnectKcm::rejectPairing);
+    connect(kcmUi->pair_button, &QAbstractButton::clicked,
+            this, &KdeConnectKcm::requestPair);
+    connect(kcmUi->unpair_button, &QAbstractButton::clicked,
+            this, &KdeConnectKcm::unpair);
+    connect(kcmUi->ping_button, &QAbstractButton::clicked,
+            this, &KdeConnectKcm::sendPing);
+    connect(kcmUi->refresh_button,&QAbstractButton::clicked,
+            this, &KdeConnectKcm::refresh);
+    connect(kcmUi->rename_edit,&QLineEdit::returnPressed,
+            this, &KdeConnectKcm::renameDone);
+    connect(kcmUi->renameDone_button,&QAbstractButton::clicked,
+            this, &KdeConnectKcm::renameDone);
+    connect(kcmUi->renameShow_button,&QAbstractButton::clicked,
+            this, &KdeConnectKcm::renameShow);
 
     daemon->acquireDiscoveryMode(createId());
 }
@@ -180,21 +188,23 @@ void KdeConnectKcm::deviceSelected(const QModelIndex& current)
     }
 
     kcmUi->messages->setVisible(false);
-    kcmUi->progressBar->setVisible(false);
-    if (currentDevice->isTrusted()) {
-        kcmUi->unpair_button->setVisible(true);
-        kcmUi->pair_button->setVisible(false);
-        kcmUi->ping_button->setVisible(true);
-    } else {
-        kcmUi->unpair_button->setVisible(false);
-        kcmUi->pair_button->setVisible(true);
-        kcmUi->ping_button->setVisible(false);
-    }
     resetDeviceView();
 
     connect(currentDevice, SIGNAL(pluginsChanged()), this, SLOT(resetCurrentDevice()));
     connect(currentDevice, SIGNAL(trustedChanged(bool)), this, SLOT(trustedChanged(bool)));
     connect(currentDevice, SIGNAL(pairingError(QString)), this, SLOT(pairingFailed(QString)));
+    connect(currentDevice, &DeviceDbusInterface::hasPairingRequestsChangedProxy, this, &KdeConnectKcm::currentDevicePairingChanged);
+}
+
+void KdeConnectKcm::currentDevicePairingChanged(bool pairing)
+{
+    if (pairing) {
+        setCurrentDeviceTrusted(RequestedByPeer);
+    } else {
+        setWhenAvailable(currentDevice->isTrusted(), [this](bool trusted) {
+            setCurrentDeviceTrusted(trusted ? Trusted : NotTrusted);
+        }, this);
+    }
 }
 
 void KdeConnectKcm::resetCurrentDevice()
@@ -216,9 +226,16 @@ void KdeConnectKcm::resetDeviceView()
     kcmUi->pluginSelector->setConfigurationArguments(QStringList(currentDevice->id()));
 
     kcmUi->name_label->setText(currentDevice->name());
-    kcmUi->status_label->setText(currentDevice->isTrusted()? i18n("(trusted)") : i18n("(not trusted)"));
+    setWhenAvailable(currentDevice->isTrusted(), [this](bool trusted) {
+        if (trusted)
+            setCurrentDeviceTrusted(Trusted);
+        else
+            setWhenAvailable(currentDevice->hasPairingRequests(), [this](bool haspr) {
+                setCurrentDeviceTrusted(haspr ? RequestedByPeer : NotTrusted);
+            }, this);
+    }, this);
 
-    const QList<KPluginInfo> pluginInfo = KPluginInfo::fromMetaData(KPluginLoader::findPlugins("kdeconnect/"));
+    const QList<KPluginInfo> pluginInfo = KPluginInfo::fromMetaData(KPluginLoader::findPlugins(QStringLiteral("kdeconnect/")));
     QList<KPluginInfo> availablePluginInfo;
 
     m_oldSupportedPluginNames = currentDevice->supportedPlugins();
@@ -230,7 +247,7 @@ void KdeConnectKcm::resetDeviceView()
 
     KSharedConfigPtr deviceConfig = KSharedConfig::openConfig(currentDevice->pluginsConfigFile());
     kcmUi->pluginSelector->addPlugins(availablePluginInfo, KPluginSelector::ReadConfigFile, i18n("Available plugins"), QString(), deviceConfig);
-    connect(kcmUi->pluginSelector, SIGNAL(changed(bool)), this, SLOT(pluginsConfigChanged()));
+    connect(kcmUi->pluginSelector, &KPluginSelector::changed, this, &KdeConnectKcm::pluginsConfigChanged);
 
 }
 
@@ -242,8 +259,7 @@ void KdeConnectKcm::requestPair()
 
     kcmUi->messages->hide();
 
-    kcmUi->pair_button->setVisible(false);
-    kcmUi->progressBar->setVisible(true);
+    setCurrentDeviceTrusted(Requested);
 
     currentDevice->requestPair();
 
@@ -255,29 +271,67 @@ void KdeConnectKcm::unpair()
         return;
     }
 
+    setCurrentDeviceTrusted(NotTrusted);
     currentDevice->unpair();
 }
 
+void KdeConnectKcm::acceptPairing()
+{
+    if (!currentDevice) {
+        return;
+    }
+
+    currentDevice->acceptPairing();
+}
+
+void KdeConnectKcm::rejectPairing()
+{
+    if (!currentDevice) {
+        return;
+    }
+
+    currentDevice->rejectPairing();
+}
+
 void KdeConnectKcm::pairingFailed(const QString& error)
 {
     if (sender() != currentDevice) return;
 
-    trustedChanged(false);
+    setCurrentDeviceTrusted(NotTrusted);
 
     kcmUi->messages->setText(i18n("Error trying to pair: %1",error));
     kcmUi->messages->animatedShow();
 }
 
-void KdeConnectKcm::trustedChanged(bool paired)
+void KdeConnectKcm::trustedChanged(bool trusted)
 {
     DeviceDbusInterface* senderDevice = (DeviceDbusInterface*) sender();
-    if (senderDevice != currentDevice) return;
+    if (senderDevice == currentDevice)
+        setCurrentDeviceTrusted(trusted ? Trusted : NotTrusted);
+}
 
-    kcmUi->pair_button->setVisible(!paired);
-    kcmUi->unpair_button->setVisible(paired);
-    kcmUi->progressBar->setVisible(false);
-    kcmUi->ping_button->setVisible(paired);
-    kcmUi->status_label->setText(paired ? i18n("(paired)") : i18n("(unpaired)"));
+void KdeConnectKcm::setCurrentDeviceTrusted(KdeConnectKcm::TrustStatus trusted)
+{
+    kcmUi->accept_button->setVisible(trusted == RequestedByPeer);
+    kcmUi->reject_button->setVisible(trusted == RequestedByPeer);
+    kcmUi->pair_button->setVisible(trusted == NotTrusted);
+    kcmUi->unpair_button->setVisible(trusted == Trusted);
+    kcmUi->progressBar->setVisible(trusted == Requested);
+    kcmUi->ping_button->setVisible(trusted == Trusted);
+    switch (trusted) {
+        case Trusted:
+            kcmUi->status_label->setText(i18n("(paired)"));
+            break;
+        case NotTrusted:
+            kcmUi->status_label->setText(i18n("(not paired)"));
+            break;
+        case RequestedByPeer:
+            kcmUi->status_label->setText(i18n("(incoming pair request)"));
+            break;
+        case Requested:
+            kcmUi->status_label->setText(i18n("(pairing requested)"));
+            break;
+    }
 }
 
 void KdeConnectKcm::pluginsConfigChanged()
@@ -302,7 +356,7 @@ void KdeConnectKcm::save()
 void KdeConnectKcm::sendPing()
 {
     if (!currentDevice) return;
-    currentDevice->pluginCall("ping", "sendPing");
+    currentDevice->pluginCall(QStringLiteral("ping"), QStringLiteral("sendPing"));
 }
 
 QSize KdeConnectKcm::sizeHint() const
