@@ -21,11 +21,10 @@
 #ifndef NOTIFICATIONSPLUGIN_H
 #define NOTIFICATIONSPLUGIN_H
 
-#include <knotification.h>
-
 #include <core/kdeconnectplugin.h>
 
-#define PACKAGE_TYPE_NOTIFICATION_REQUEST QLatin1String("kdeconnect.notification.request")
+#define PACKET_TYPE_NOTIFICATION_REQUEST QStringLiteral("kdeconnect.notification.request")
+#define PACKET_TYPE_NOTIFICATION_REPLY QStringLiteral("kdeconnect.notification.reply")
 
 /*
  * This class is just a proxy for NotificationsDbusInterface
@@ -41,11 +40,10 @@ class NotificationsPlugin
     Q_OBJECT
 
 public:
-    explicit NotificationsPlugin(QObject *parent, const QVariantList &args);
+    explicit NotificationsPlugin(QObject* parent, const QVariantList& args);
     ~NotificationsPlugin() override;
-    
-public Q_SLOTS:
-    bool receivePackage(const NetworkPackage& np) override;
+
+    bool receivePacket(const NetworkPacket& np) override;
     void connected() override;
 
 protected:
