@@ -28,7 +28,7 @@
 
 K_PLUGIN_FACTORY(ShareConfigFactory, registerPlugin<ShareConfig>();)
 
-ShareConfig::ShareConfig(QWidget *parent, const QVariantList& args)
+ShareConfig::ShareConfig(QWidget* parent, const QVariantList& args)
     : KdeConnectPluginKcm(parent, args, QStringLiteral("kdeconnect_share_config"))
     , m_ui(new Ui::ShareConfigUi())
 {
@@ -49,7 +49,7 @@ void ShareConfig::defaults()
 {
     KCModule::defaults();
 
-    m_ui->kurlrequester->setUrl(QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DownloadLocation)));
+    m_ui->kurlrequester->setText(QStandardPaths::writableLocation(QStandardPaths::DownloadLocation));
 
     Q_EMIT changed(true);
 }
@@ -58,7 +58,8 @@ void ShareConfig::load()
 {
     KCModule::load();
 
-    m_ui->kurlrequester->setUrl(QUrl::fromLocalFile(config()->get(QStringLiteral("incoming_path"), QStandardPaths::writableLocation(QStandardPaths::DownloadLocation))));
+    const auto standardPath = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
+    m_ui->kurlrequester->setText(config()->get<QString>(QStringLiteral("incoming_path"), standardPath));
 
     Q_EMIT changed(false);
 }
