@@ -21,12 +21,11 @@
 #ifndef SHAREPLUGIN_H
 #define SHAREPLUGIN_H
 
-#include <KNotification>
 #include <KIO/Job>
 
 #include <core/kdeconnectplugin.h>
 
-#define PACKAGE_TYPE_SHARE_REQUEST QLatin1String("kdeconnect.share.request")
+#define PACKET_TYPE_SHARE_REQUEST QStringLiteral("kdeconnect.share.request")
 
 class SharePlugin
     : public KdeConnectPlugin
@@ -35,25 +34,25 @@ class SharePlugin
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.share")
 
 public:
-    explicit SharePlugin(QObject *parent, const QVariantList &args);
+    explicit SharePlugin(QObject* parent, const QVariantList& args);
 
     ///Helper method, QDBus won't recognize QUrl
     Q_SCRIPTABLE void shareUrl(const QString& url) { shareUrl(QUrl(url)); }
-public Q_SLOTS:
-    bool receivePackage(const NetworkPackage& np) override;
-    void connected() override;
+
+    bool receivePacket(const NetworkPacket& np) override;
+    void connected() override {}
+    QString dbusPath() const override;
 
 private Q_SLOTS:
     void finished(KJob*);
     void openDestinationFolder();
 
 Q_SIGNALS:
-    void shareReceived(const QUrl& url);
+    void shareReceived(const QString& url);
 
 private:
     void shareUrl(const QUrl& url);
 
-    QString dbusPath() const;
     QUrl destinationDir() const;
 
 };
